Venv-Pack
==========

``venv-pack`` is a command line tool for creating relocatable `virtual
environments`_.

See `conda-pack`_ for a similar tool for `conda environments`_.

LICENSE
-------

New BSD. See the
`License File <https://github.com/jcrist/venv-pack/blob/master/LICENSE.txt>`_.

.. _virtual environments: https://docs.python.org/3/tutorial/venv.html
.. _conda environments: https://conda.io
.. _conda-pack: https://conda.github.io/conda-pack/
